pecos.tools.tool\_collection
============================

.. automodule:: pecos.tools.tool_collection

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      fault_tolerance_check
      form_errors
      gen_pauli_errors
   
   

   
   
   

   
   
   



